@@ -2,13 +2,24 @@ require ("prototypes.entity.rail-pictures")
 
 local hit_effects = require ("prototypes.entity.hit-effects")
 local sounds = require("prototypes.entity.sounds")
+local tile_sounds = require("prototypes.tile.tile-sounds")
 local simulations = require("__base__.prototypes.factoriopedia-simulations")
 
 local drive_over_tie = function()
   return
   {
     type = "play-sound",
-    sound = sound_variations("__base__/sound/train-tie", 6, 0.4, { volume_multiplier("main-menu", 2.4), volume_multiplier("driving", 1.3) } )
+    sound =
+    {
+      category = "environment",
+      variations = sound_variations("__base__/sound/train-tie",
+                                    6,
+                                    0.4,
+                                    {
+                                      volume_multiplier("main-menu", 2.4),
+                                      volume_multiplier("driving", 1.3)
+                                    })
+    }
   }
 end
 
@@ -149,7 +160,7 @@ data:extend(
     damaged_trigger_effect = hit_effects.wall(),
     pictures = legacy_rail_pictures("legacy_straight_rail"),
     placeable_by = {item = "rail", count = 1},
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     deconstruction_marker_positions =
     {
       { 0.0, 0.0 }, -- North
@@ -204,7 +215,7 @@ data:extend(
     pictures = legacy_rail_pictures("legacy_curved_rail"),
     ending_shifts = curved_rail_ending_shifts(),
     placeable_by = {item = "rail", count = 4},
-    walking_sound = sounds.rails
+    walking_sound = tile_sounds.walking.rails
   },
   {
     type = "straight-rail",
@@ -236,7 +247,7 @@ data:extend(
     damaged_trigger_effect = hit_effects.wall(),
     pictures = new_rail_pictures("straight"),
     placeable_by = {item = "rail", count = 1},
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     extra_planner_goal_penalty = -4,
     factoriopedia_alternative = "straight-rail"
   },
@@ -283,7 +294,7 @@ data:extend(
     damaged_trigger_effect = hit_effects.wall(),
     pictures = new_rail_pictures("half-diagonal"),
     placeable_by = {item = "rail", count = 2},
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     extra_planner_penalty = 0,
     factoriopedia_alternative = "straight-rail"
   },
@@ -328,7 +339,7 @@ data:extend(
     damaged_trigger_effect = hit_effects.wall(),
     pictures = new_rail_pictures("curved-a"),
     placeable_by = {item = "rail", count = 3},
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     extra_planner_penalty = 0.5,
     deconstruction_marker_positions = rail_8shifts_vector(-0.248, -0.533),
     factoriopedia_alternative = "straight-rail"
@@ -374,7 +385,7 @@ data:extend(
     damaged_trigger_effect = hit_effects.wall(),
     pictures = new_rail_pictures("curved-b"),
     placeable_by = {item = "rail", count = 3},
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     extra_planner_penalty = 0.5,
     deconstruction_marker_positions = rail_8shifts_vector(-0.309, -0.155),
     factoriopedia_alternative = "straight-rail"
@@ -393,7 +404,7 @@ data:extend(
     selection_box = {{-1.7, -0.8}, {1.7, 0.8}},
     pictures = dummy_rails_ramp_pictures(),
     forced_fence_segment_count = 2,
-    walking_sound = sounds.rails,
+    walking_sound = tile_sounds.walking.rails,
     extra_planner_penalty = 0.5,
     support_range = 9
   },
@@ -794,7 +805,7 @@ data:extend(
           },
         },
       },
-      max_sounds_per_type = 2,
+      max_sounds_per_prototype = 2,
       activate_sound = { filename = "__base__/sound/train-engine-start.ogg", volume = 0.35 },
       deactivate_sound = { filename = "__base__/sound/train-engine-stop.ogg", volume = 0.35 },
     },
@@ -1600,11 +1611,7 @@ data:extend(
     color={0.95, 0, 0, 1},
     open_sound = {filename = "__base__/sound/open-close/train-stop-open.ogg", volume = 0.6},
     close_sound = {filename = "__base__/sound/open-close/train-stop-close.ogg", volume = 0.5},
-    working_sound =
-    {
-      sound = { filename = "__base__/sound/train-stop.ogg", volume = 0.7 },
-      audible_distance_modifier = 0.2
-    },
+    working_sound = {filename = "__base__/sound/train-stop.ogg", volume = 0.7, audible_distance_modifier = 0.2},
 
     circuit_connector = circuit_connector_definitions["train-station"],
     circuit_wire_max_distance = default_circuit_wire_max_distance,
@@ -1665,3 +1672,14 @@ data:extend(
   }
 }
 )
+
+local infinity_cargo_wagon = table.deepcopy(data.raw["cargo-wagon"]["cargo-wagon"])
+infinity_cargo_wagon.type = "infinity-cargo-wagon"
+infinity_cargo_wagon.name = "infinity-cargo-wagon"
+infinity_cargo_wagon.icon = nil
+infinity_cargo_wagon.icons = {{icon = "__base__/graphics/icons/cargo-wagon.png", tint = {r = 0.5, g = 0.5, b = 1}}}
+infinity_cargo_wagon.gui_mode = "admins"
+infinity_cargo_wagon.minable = {mining_time = 0.1, result = "infinity-cargo-wagon"}
+infinity_cargo_wagon.hidden = true
+util.recursive_tint(infinity_cargo_wagon, {r = 0.5, g = 0.5, b = 1})
+data:extend({infinity_cargo_wagon})
