@@ -271,9 +271,8 @@ data:extend
 
     working_sound =
     {
-      sound = { filename = "__base__/sound/underground-belt.ogg", volume = 0.2 },
-      max_sounds_per_type = 2,
-      audible_distance_modifier = 0.5,
+      sound = {filename = "__base__/sound/underground-belt.ogg", volume = 0.2, audible_distance_modifier = 0.5},
+      max_sounds_per_prototype = 2,
       persistent = true,
       use_doppler_shift = false
     },
@@ -397,9 +396,8 @@ data:extend
     close_sound = sounds.machine_close,
     working_sound =
     {
-      sound = { filename = "__base__/sound/fast-underground-belt.ogg", volume = 0.27 },
-      max_sounds_per_type = 2,
-      audible_distance_modifier = 0.5,
+      sound = {filename = "__base__/sound/fast-underground-belt.ogg", volume = 0.27, audible_distance_modifier = 0.5},
+      max_sounds_per_prototype = 2,
       persistent = true,
       use_doppler_shift = false
     },
@@ -551,9 +549,8 @@ data:extend
     close_sound = sounds.machine_close,
     working_sound =
     {
-      sound = { filename = "__base__/sound/express-underground-belt.ogg", volume = 0.35 },
-      max_sounds_per_type = 2,
-      audible_distance_modifier = 0.5,
+      sound = {filename = "__base__/sound/express-underground-belt.ogg", volume = 0.35, audible_distance_modifier = 0.5},
+      max_sounds_per_prototype = 2,
       persistent = true,
       use_doppler_shift = false
     },
@@ -974,6 +971,7 @@ data:extend
     collision_box = {{-0.4, -0.9}, {0.4, 0.9}},
     selection_box = {{-0.5, -1}, {0.5, 1}},
     animation_speed_coefficient = 32,
+    icon_draw_specification = {scale = 0.7},
     belt_animation_set = basic_belt_animation_set,
     fast_replaceable_group = "loader",
     speed = 0.03125,
@@ -1016,6 +1014,7 @@ data:extend
     collision_box = {{-0.4, -0.4}, {0.4, 0.4}},
     selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
     animation_speed_coefficient = 32,
+    icon_draw_specification = {scale = 0.7},
     belt_animation_set = basic_belt_animation_set,
     container_distance = 1,
     speed = 0.03125,
@@ -1069,6 +1068,7 @@ data:extend
     selection_box = {{-0.5, -1}, {0.5, 1}},
     damaged_trigger_effect = hit_effects.entity(),
     animation_speed_coefficient = 32,
+    icon_draw_specification = {scale = 0.7},
     belt_animation_set = fast_belt_animation_set,
     fast_replaceable_group = "loader",
     speed = 0.0625,
@@ -1124,6 +1124,7 @@ data:extend
     selection_box = {{-0.5, -1}, {0.5, 1}},
     damaged_trigger_effect = hit_effects.entity(),
     animation_speed_coefficient = 32,
+    icon_draw_specification = {scale = 0.7},
     belt_animation_set = express_belt_animation_set,
     fast_replaceable_group = "loader",
     speed = 0.09375,
